@@ -2,32 +2,25 @@ package Acme::CPANAuthors::Korean;
 
 use strict;
 use warnings;
-our $VERSION = '0.011';
+our $VERSION = '0.03';
 
 use Acme::CPANAuthors::Register (
-    AANOAA   => "Hyungsuk Hong",
-    AERO     => "C.H. Kang",
-    AMORETTE => "Hojung Youn",
-    DALINAUM => "김용욱 (Leonaro YongUk KIM)",
-    GYPARK   => "Geunyoung Park",
-    JEEN     => "Jong-jin Lee",
-    JPJEON   => "Jongpil Jeon",
-    KEEDI    => "Keedi Kim",
-    KHS      => "HyeonSeung Kim",
-    NEWBCODE => "Yun Chang Kang",
-    YONGBIN  => "Yongbin Yu",
-    YOU      => "YOU Hyun Jo",
+	JEEN => "Jong-jin Lee",
+	AERO => "C.H. Kang",
+	KEEDI => "Keedi Kim",
+	YOU => "YOU Hyun Jo",
+        KHS => "HyeonSeung Kim"
 );
 
 1;
 
 __END__
 
-=encoding utf8
+=encoding utf-8
 
 =head1 NAME
 
-Acme::CPANAuthors::Korean - We are Korean CPAN Authors! (우리는 CPAN Author 다!)
+Acme::CPANAuthors::Korean - We are Korean CPAN Authors!
 
 =head1 SYNOPSIS
 
@@ -55,7 +48,7 @@ Git repository: http://github.com/jeen/Acme-CPANAuthors-Korean/
 
 =head1 AUTHOR
 
-Jeen Lee E<lt>jeen@perl.krE<gt>
+JEEN E<lt>jeen@perl.krE<gt>
 
 =head1 SEE ALSO
 
@@ -64,4 +57,4 @@ Jeen Lee E<lt>jeen@perl.krE<gt>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
